# Counterfactual CoT Analyzer

Analyze chain-of-thought reasoning for signs of strategic behavior.

## CounterfactualCoTAnalyzer

::: rotalabs_probe.analyzers.counterfactual_cot.CounterfactualCoTAnalyzer

## InterventionType

::: rotalabs_probe.InterventionType

## ReasoningType

::: rotalabs_probe.ReasoningType

## ReasoningNode

::: rotalabs_probe.ReasoningNode

## ModelAPI

::: rotalabs_probe.analyzers.model_api.ModelAPI
